/*
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

  As a special exception, permission is given to link this program
  with any edition of Qt, and distribute the resulting executable,
  without including the source code for Qt in the source distribution.
*/

#include "MabumbiSysTray.h"

#include <KDE/KAction>
#include <KDE/KActionCollection>
#include <KDE/KIconLoader>

#include <QIcon>
#include <QMenu>

MabumbiSysTray::MabumbiSysTray( QWidget* parent )
        : KSystemTrayIcon(parent)
{
    buildContextMenu();
    setIcon( idleIcon() );
}

MabumbiSysTray::~MabumbiSysTray()
{
}

QIcon MabumbiSysTray::runningIcon()
{
    QPixmap pix = KIconLoader::global()->loadIcon( "mabumbi-running", KIconLoader::NoGroup, 32 );
    return QIcon( pix );
}

QIcon MabumbiSysTray::idleIcon()
{
    QPixmap pix = KIconLoader::global()->loadIcon( "mabumbi-isidle", KIconLoader::NoGroup, 32 );
    return QIcon( pix );
}

QIcon MabumbiSysTray::disconnectedIcon()
{
    QPixmap pix = KIconLoader::global()->loadIcon( "mabumbi-disconnected", KIconLoader::NoGroup, 32 );
    return QIcon( pix );
}

QIcon MabumbiSysTray::errorIcon()
{
    QPixmap pix = KIconLoader::global()->loadIcon( "mabumbi-error", KIconLoader::NoGroup, 32 );
    return QIcon( pix );
}

void MabumbiSysTray::backupRunning()
{
    setIcon( runningIcon() );
    setToolTip( "Backup is running" );
}

void MabumbiSysTray::backupIdle()
{
    setIcon( idleIcon() );
    setToolTip( "Backup is idle" );
}

void MabumbiSysTray::destinationConnected()
{
    backupIdle();
}

void MabumbiSysTray::destinationDisconnected()
{
    setIcon( disconnectedIcon() );
    setToolTip( "Backup destination is not available" );
}

void MabumbiSysTray::backupError()
{
    setIcon( errorIcon() );
    setToolTip( "Backup error" );
}

void MabumbiSysTray::buildContextMenu()
{
    QMenu* contextM = contextMenu();
    KActionCollection* actionCollect = actionCollection();
    QAction* actionStart = actionCollect->action( "Start_Backup" );
    if ( actionStart != 0 )
        contextM->addAction( actionStart );
    QAction* actionOpen = actionCollect->action( "Open_Backup" );
    if ( actionOpen != 0 )
        contextM->addAction( actionOpen );

    QAction* titleAction = contextMenuTitle();
    titleAction->setText( "Mabumbi Backup" );
    setContextMenuTitle( titleAction );
}

#include "MabumbiSysTray.moc"
